@@ -12,7 +12,7 @@ class DeviceFactory:
         if "MOWER" in device_map:
             return Mower(location, device_map)
         elif "SENSOR" in device_map:
-            if 'ambientTemperature' in device_map['SENSOR'][0]['attributes']:
+            if "ambientTemperature" in device_map["SENSOR"][0]["attributes"]:
                 return Sensor(location, device_map)
             return SoilSensor(location, device_map)
         elif "POWER_SOCKET" in device_map:
